# burro

[![Build Status](https://travis-ci.org/kosmitive/burro.png?branch=develop)](https://travis-ci.org/kosmitive/burro)

# Supply chain simulations / Beer game

This is a small framework for supply chain simulations released by xploras. It is made such that each participant in the
chain can not see the full information but has access to previous and following nodes.

# Install necessary packages

You have to create an environment with the relevant libraries.

```
pip install numpy matplotlib
```

# Run the refill agent example

To start the agent simply run the following:
```
python examples/run_refill_agent.py
```

# Install burro as pip package
```
pip install -e .
```

## Contributors

[Markus Semmler](https://github.com/kosmitive/ )

[Thomas Lautenschläger](https://github.com/kosmitive/ )